@@ -10,6 +10,7 @@ class Config {
 
 	enum { min_details = 0, max_details = 4 };
 	int details_level_;
+	int refresh_rate_;
 	const std::string player_name_;
 	const std::string score_file_name_;
 
@@ -24,6 +25,9 @@ public:
 	int ScaleDetails(int val) const
 		{ return val * details_level_ / max_details; }
 	int MaxDetails() const { return max_details; }
+	int RefreshRate(void) const { return refresh_rate_; }
+	int NextRefreshRate(void) const;
+	void SetNextRefreshRate(void) { refresh_rate_ = NextRefreshRate(); }
 	const std::string & GetPlayerName() const { return player_name_; }
 	const std::string & GetScoreFileName() const { return score_file_name_; }
 };
