@@ -35,22 +35,25 @@ inline bool operator<(const HighScore & lhs, const HighScore & rhs)
 class HighScores {
 	static HighScores * singleton_;
 
-	typedef std::map<Coord, std::multiset<HighScore> > Ctn;
-	Ctn high_scores_;
+	typedef std::map<Coord, std::multiset<HighScore> > MapCoordScore;
+	typedef std::map<int, MapCoordScore> MapRateCoordScore;
+	MapRateCoordScore high_scores_;
 	int last_score_;
 	Coord last_size_;
+	int last_rate_;
 
 	HighScores() : last_score_(-1) {}
 public:
 	static HighScores & Instance();
 	static void DestroyInstance() { delete singleton_; singleton_ = 0; }
 
-	void Add(int score, Coord window_size) {
+	void Add(int score, Coord window_size, int refresh_rate) {
 		last_score_ = score;
 		last_size_ = window_size;
+		last_rate_ = refresh_rate;
 	}
 	void Update();
-	const std::multiset<HighScore> * Get(Coord window_size) const;
+	const std::multiset<HighScore> * Get(Coord window_size, int refresh_rate) const;
 private:
 	void Load(std::istream &);
 	void Save(std::ostream &) const;
